@@ -9,6 +9,7 @@ from mdpo.command import (
     normalize_mdpo_command_aliases,
     parse_mdpo_html_command,
 )
+from mdpo.event import raise_skip_event
 from mdpo.io import filter_paths, to_glob_or_content
 from mdpo.md import parse_link_references
 from mdpo.md4c import (
@@ -146,7 +147,10 @@ class Md2Po:
         )
         self.events = {}
         if 'events' in kwargs:
-            self.events.update(kwargs['events'])
+            for event_name, functions in kwargs['events'].items():
+                self.events[event_name] = (
+                    [functions] if callable(functions) else functions
+                )
 
         self.plaintext = kwargs.get('plaintext', False)
 
@@ -212,30 +216,30 @@ class Md2Po:
                 })
 
             self._enterspan_replacer = {
-                md4c.SpanType.STRONG: self.bold_start_string,
-                md4c.SpanType.EM: self.italic_start_string,
-                md4c.SpanType.CODE: self.code_start_string,
-                md4c.SpanType.A: self.link_start_string,
+                md4c.SpanType.STRONG.value: self.bold_start_string,
+                md4c.SpanType.EM.value: self.italic_start_string,
+                md4c.SpanType.CODE.value: self.code_start_string,
+                md4c.SpanType.A.value: self.link_start_string,
             }
 
             self._leavespan_replacer = {
-                md4c.SpanType.STRONG: self.bold_end_string,
-                md4c.SpanType.EM: self.italic_end_string,
-                md4c.SpanType.CODE: self.code_end_string,
-                md4c.SpanType.A: self.link_end_string,
+                md4c.SpanType.STRONG.value: self.bold_end_string,
+                md4c.SpanType.EM.value: self.italic_end_string,
+                md4c.SpanType.CODE.value: self.code_end_string,
+                md4c.SpanType.A.value: self.link_end_string,
             }
 
             if 'strikethrough' in self.extensions:
                 self.strikethrough_start_string = kwargs.get(
                     'strikethrough_start_string', '~~',
                 )
-                self._enterspan_replacer[md4c.SpanType.DEL] = \
+                self._enterspan_replacer[md4c.SpanType.DEL.value] = \
                     self.strikethrough_start_string
 
                 self.strikethrough_end_string = kwargs.get(
                     'strikethrough_end_string', '~~',
                 )
-                self._leavespan_replacer[md4c.SpanType.DEL] = \
+                self._leavespan_replacer[md4c.SpanType.DEL.value] = \
                     self.strikethrough_end_string
 
                 if _include_xheaders:
@@ -250,26 +254,28 @@ class Md2Po:
                 self.latexmath_start_string = kwargs.get(
                     'latexmath_start_string', '$',
                 )
-                self._enterspan_replacer[md4c.SpanType.LATEXMATH] = \
+                self._enterspan_replacer[md4c.SpanType.LATEXMATH.value] = \
                     self.latexmath_start_string
 
                 self.latexmath_end_string = kwargs.get(
                     'latexmath_end_string', '$',
                 )
-                self._leavespan_replacer[md4c.SpanType.LATEXMATH] = \
+                self._leavespan_replacer[md4c.SpanType.LATEXMATH.value] = \
                     self.latexmath_end_string
 
                 self.latexmathdisplay_start_string = kwargs.get(
                     'latexmathdisplay_start_string', '$$',
                 )
-                self._enterspan_replacer[md4c.SpanType.LATEXMATH_DISPLAY] = \
-                    self.latexmathdisplay_start_string
+                self._enterspan_replacer[
+                    md4c.SpanType.LATEXMATH_DISPLAY.value
+                ] = self.latexmathdisplay_start_string
 
                 self.latexmathdisplay_end_string = kwargs.get(
                     'latexmathdisplay_end_string', '$$',
                 )
-                self._leavespan_replacer[md4c.SpanType.LATEXMATH_DISPLAY] = \
-                    self.latexmathdisplay_end_string
+                self._leavespan_replacer[
+                    md4c.SpanType.LATEXMATH_DISPLAY.value
+                ] = self.latexmathdisplay_end_string
 
                 if _include_xheaders:
                     self.metadata.update({
@@ -289,9 +295,9 @@ class Md2Po:
                     'wikilink_end_string', ']]',
                 )
 
-                self._enterspan_replacer[md4c.SpanType.WIKILINK] = \
+                self._enterspan_replacer[md4c.SpanType.WIKILINK.value] = \
                     self.wikilink_start_string
-                self._leavespan_replacer[md4c.SpanType.WIKILINK] = \
+                self._leavespan_replacer[md4c.SpanType.WIKILINK.value] = \
                     self.wikilink_end_string
 
                 if _include_xheaders:
@@ -305,13 +311,13 @@ class Md2Po:
                 self.underline_start_string = kwargs.get(
                     'underline_start_string', '__',
                 )
-                self._enterspan_replacer[md4c.SpanType.U] = \
+                self._enterspan_replacer[md4c.SpanType.U.value] = \
                     self.underline_start_string
 
                 self.underline_end_string = kwargs.get(
                     'underline_end_string', '__',
                 )
-                self._leavespan_replacer[md4c.SpanType.U] = \
+                self._leavespan_replacer[md4c.SpanType.U.value] = \
                     self.underline_end_string
 
                 if _include_xheaders:
@@ -410,13 +416,17 @@ class Md2Po:
 
     def _save_current_msgid(self, msgstr='', fuzzy=False):
         # raise 'msgid' event
-        try:
-            pre_event = self.events['msgid']
-        except KeyError:
-            pass
-        else:
-            if pre_event(self, self._current_msgid) is False:
-                return
+        if raise_skip_event(
+            self.events,
+            'msgid',
+            self,
+            self._current_msgid,
+            msgstr,
+            self._current_msgctxt,
+            self._current_tcomment,
+            ['fuzzy'] if fuzzy else [],
+        ):
+            return
 
         if self._current_msgid:
             if (not self._disable_next_line and not self._disable) or \
@@ -424,8 +434,8 @@ class Md2Po:
                 self._save_msgid(
                     self._current_msgid,
                     msgstr=msgstr or self.msgstr,
-                    tcomment=self._current_tcomment,
                     msgctxt=self._current_msgctxt,
+                    tcomment=self._current_tcomment,
                     fuzzy=fuzzy,
                 )
             else:
@@ -433,9 +443,9 @@ class Md2Po:
                     polib.POEntry(
                         msgid=self._current_msgid,
                         msgstr=msgstr or self.msgstr,
-                        comment=self._current_tcomment,
                         msgctxt=self._current_msgctxt,
-                        fuzzy=fuzzy,
+                        tcomment=self._current_tcomment,
+                        flags=['fuzzy'] if fuzzy else [],
                     ),
                 )
         self._disable_next_line = False
@@ -446,18 +456,15 @@ class Md2Po:
 
     def command(self, mdpo_command, comment, original_command):
         # raise 'command' event
-        try:
-            pre_event = self.events['command']
-        except KeyError:
-            pass
-        else:
-            if pre_event(
-                self,
-                mdpo_command,
-                comment,
-                original_command,
-            ) is False:
-                return
+        if raise_skip_event(
+            self.events,
+            'command',
+            self,
+            mdpo_command,
+            comment,
+            original_command,
+        ):
+            return
 
         if mdpo_command == 'mdpo-disable-next-line':
             self._disable_next_line = True
@@ -517,15 +524,10 @@ class Md2Po:
         # print("ENTER BLOCK:", block.name)
 
         # raise 'enter_block' event
-        try:
-            pre_event = self.events['enter_block']
-        except KeyError:
-            pass
-        else:
-            if pre_event(self, block, details) is False:
-                return
+        if raise_skip_event(self.events, 'enter_block', self, block, details):
+            return
 
-        if block.value == md4c.BlockType.P:
+        if block is md4c.BlockType.P:
             self._inside_pblock = True
             if not any([
                 self._inside_hblock,
@@ -535,7 +537,7 @@ class Md2Po:
             ]):
                 self._current_top_level_block_number += 1
                 self._current_top_level_block_type = md4c.BlockType.P.value
-        elif block.value == md4c.BlockType.CODE:
+        elif block is md4c.BlockType.CODE:
             self._inside_codeblock = True
             if not any([
                 self._quoteblocks_deep,
@@ -544,9 +546,9 @@ class Md2Po:
             ]):
                 self._current_top_level_block_number += 1
                 self._current_top_level_block_type = md4c.BlockType.CODE.value
-        elif block.value == md4c.BlockType.LI:
+        elif block is md4c.BlockType.LI:
             self._inside_liblock = True
-        elif block.value == md4c.BlockType.UL:
+        elif block is md4c.BlockType.UL:
             self._uls_deep += 1
             if self._uls_deep > 1 or self._inside_olblock:
                 # changing UL deeep
@@ -557,7 +559,7 @@ class Md2Po:
             ]):
                 self._current_top_level_block_number += 1
                 self._current_top_level_block_type = md4c.BlockType.UL.value
-        elif block.value == md4c.BlockType.H:
+        elif block is md4c.BlockType.H:
             self._inside_hblock = True
             if not any([
                 self._quoteblocks_deep,
@@ -566,14 +568,14 @@ class Md2Po:
             ]):
                 self._current_top_level_block_number += 1
                 self._current_top_level_block_type = md4c.BlockType.H.value
-        elif block.value == md4c.BlockType.QUOTE:
+        elif block is md4c.BlockType.QUOTE:
             self._quoteblocks_deep += 1
             if self._inside_liblock:
                 self._save_current_msgid()
             if self._quoteblocks_deep == 1:
                 self._current_top_level_block_number += 1
                 self._current_top_level_block_type = md4c.BlockType.QUOTE.value
-        elif block.value == md4c.BlockType.OL:
+        elif block is md4c.BlockType.OL:
             if not any([
                 self._quoteblocks_deep,
                 self._uls_deep,
@@ -585,7 +587,7 @@ class Md2Po:
             if self._inside_olblock or self._uls_deep:
                 self._save_current_msgid()
             self._inside_olblock = True
-        elif block.value == md4c.BlockType.HTML:
+        elif block is md4c.BlockType.HTML:
             self._inside_htmlblock = True
             if not any([
                 self._quoteblocks_deep,
@@ -594,7 +596,7 @@ class Md2Po:
             ]):
                 self._current_top_level_block_number += 1
                 self._current_top_level_block_type = md4c.BlockType.HTML.value
-        elif block.value == md4c.BlockType.TABLE:
+        elif block is md4c.BlockType.TABLE:
             if not any([
                 self._quoteblocks_deep,
                 self._inside_olblock,
@@ -607,35 +609,30 @@ class Md2Po:
         # print("LEAVE BLOCK:", block.name)
 
         # raise 'leave_block' event
-        try:
-            pre_event = self.events['leave_block']
-        except KeyError:
-            pass
-        else:
-            if pre_event(self, block, details) is False:
-                return
+        if raise_skip_event(self.events, 'leave_block', self, block, details):
+            return
 
-        if block.value == md4c.BlockType.CODE:
+        if block is md4c.BlockType.CODE:
             self._inside_codeblock = False
             if not self._disable_next_codeblock:
                 if self.include_codeblocks or self._include_next_codeblock:
                     self._save_current_msgid()
             self._include_next_codeblock = False
             self._disable_next_codeblock = False
-        elif block.value == md4c.BlockType.HTML:
+        elif block is md4c.BlockType.HTML:
             self._inside_htmlblock = False
         else:
-            if block.value == md4c.BlockType.P:
+            if block is md4c.BlockType.P:
                 self._inside_pblock = False
-            elif block.value == md4c.BlockType.LI:
+            elif block is md4c.BlockType.LI:
                 self._inside_liblock = True
-            elif block.value == md4c.BlockType.UL:
+            elif block is md4c.BlockType.UL:
                 self._uls_deep -= 1
-            elif block.value == md4c.BlockType.H:
+            elif block is md4c.BlockType.H:
                 self._inside_hblock = False
-            elif block.value == md4c.BlockType.QUOTE:
+            elif block is md4c.BlockType.QUOTE:
                 self._quoteblocks_deep -= 1
-            elif block.value == md4c.BlockType.OL:
+            elif block is md4c.BlockType.OL:
                 self._inside_olblock = False
             self._save_current_msgid()
 
@@ -643,13 +640,8 @@ class Md2Po:
         # print("ENTER SPAN:", span.name, details)
 
         # raise 'enter_span' event
-        try:
-            pre_event = self.events['enter_span']
-        except KeyError:
-            pass
-        else:
-            if pre_event(self, span, details) is False:
-                return
+        if raise_skip_event(self.events, 'enter_span', self, span, details):
+            return
 
         if not self.plaintext:
             # underline spans for double '_' character enters two times
@@ -659,7 +651,7 @@ class Md2Po:
                 except KeyError:
                     pass
 
-            if span.value == md4c.SpanType.A:
+            if span is md4c.SpanType.A:
                 if self._link_references is None:
                     self._link_references = parse_link_references(self.content)
 
@@ -681,7 +673,7 @@ class Md2Po:
                             self._current_aspan_target = target
                             break
 
-            elif span.value == md4c.SpanType.CODE:
+            elif span is md4c.SpanType.CODE:
                 self._inside_codespan = True
 
                 # entering a code span, literal backticks encountered inside
@@ -689,17 +681,17 @@ class Md2Po:
                 #
                 # save the index char of the opening backtick
                 self._codespan_start_index = len(self._current_msgid) - 1
-            elif span.value == md4c.SpanType.IMG:
+            elif span is md4c.SpanType.IMG:
                 self._current_imgspan['src'] = details['src'][0][1]
                 self._current_imgspan['title'] = '' if not details['title'] \
                     else details['title'][0][1]
                 self._current_imgspan['text'] = ''
-            elif span.value == md4c.SpanType.U:
+            elif span is md4c.SpanType.U:
                 self._inside_uspan = True
-            elif span.value == md4c.SpanType.WIKILINK:
+            elif span is md4c.SpanType.WIKILINK:
                 self._current_wikilink_target = details['target'][0][1]
         else:
-            if span.value in (md4c.SpanType.IMG, md4c.SpanType.A) and \
+            if (span is md4c.SpanType.IMG or span is md4c.SpanType.A) and \
                     details['title']:
                 self._save_msgid(details['title'][0][1])
 
@@ -707,17 +699,12 @@ class Md2Po:
         # print("LEAVE SPAN:", span.name, details)
 
         # raise 'leave_span' event
-        try:
-            pre_event = self.events['leave_span']
-        except KeyError:
-            pass
-        else:
-            if pre_event(self, span, details) is False:
-                return
+        if raise_skip_event(self.events, 'leave_span', self, span, details):
+            return
 
         if not self.plaintext:
             if not self._inside_uspan:
-                if span.value == md4c.SpanType.WIKILINK:
+                if span is md4c.SpanType.WIKILINK:
                     self._current_msgid += self._current_wikilink_target
                     self._current_wikilink_target = None
 
@@ -726,7 +713,7 @@ class Md2Po:
                 except KeyError:
                     pass
 
-            if span.value == md4c.SpanType.A:
+            if span is md4c.SpanType.A:
                 if self._current_aspan_target:  # reference link
                     self._current_msgid += f'[{self._current_aspan_target}]'
                     self._current_aspan_target = None
@@ -737,7 +724,7 @@ class Md2Po:
                             details['title'][0][1],
                         ),
                     )
-            elif span.value == md4c.SpanType.CODE:
+            elif span is md4c.SpanType.CODE:
                 self._inside_codespan = False
                 self._codespan_start_index = None
                 # add backticks at the end for escape internal backticks
@@ -745,7 +732,7 @@ class Md2Po:
                     self._codespan_backticks * self.code_end_string
                 )
                 self._codespan_backticks = None
-            elif span.value == md4c.SpanType.IMG:
+            elif span is md4c.SpanType.IMG:
                 self._current_msgid += '![{}]({}'.format(
                     self._current_imgspan['text'],
                     self._current_imgspan['src'],
@@ -756,20 +743,15 @@ class Md2Po:
                     )
                 self._current_msgid += ')'
                 self._current_imgspan = {}
-            elif span.value == md4c.SpanType.U:
+            elif span is md4c.SpanType.U:
                 self._inside_uspan = False
 
     def text(self, block, text):
         # print(f"TEXT: '{text}'")
 
         # raise 'text' event
-        try:
-            pre_event = self.events['text']
-        except KeyError:
-            pass
-        else:
-            if pre_event(self, block, text) is False:
-                return
+        if raise_skip_event(self.events, 'text', self, block, text):
+            return
 
         if not self._inside_htmlblock:
             if not self._inside_codeblock:
@@ -823,11 +805,16 @@ class Md2Po:
             self._disable = False
 
             # 'link_reference' event
-            pre_event = self.events.get('link_reference')
+            pre_events = self.events.get('link_reference')
 
             for target, href, title in self._link_references:
-                if pre_event and pre_event(self, target, href, title) is False:
-                    continue
+                if pre_events:
+                    skip = False
+                    for event in pre_events:
+                        if event(self, target, href, title) is False:
+                            skip = True
+                    if skip:
+                        continue
 
                 self._current_msgid = '[{}]:{}{}'.format(
                     target,
@@ -1003,22 +990,37 @@ def markdown_to_pofile(
             preserving the values of the already defined.
         events (dict): Preprocessing events executed during the parsing
             process. You can use these to customize the extraction process.
-            Takes functions are values. If one of these functions returns
-            ``False``, that part of the parsing is skipped by md2po (usually a
-            MD4C event). The available events are:
+            Takes functions or list of functions as values. If one of these
+            functions returns ``False``, that part of the parsing is skipped
+            by md2po (usually a MD4C event). The available events are:
 
-            * ``enter_block``: Executed when the parsing a Markdown block
+            * ``enter_block(self, block, details)``: Executed when the parsing
+              a Markdown block starts.
+            * ``leave_block(self, block, details)``: Executed when the parsing
+              a Markdown block ends.
+            * ``enter_span(self, span, details)``: Executed when the parsing of
+              a Markdown span starts.
+            * ``leave_span(self, span, details)``: Executed when the parsing of
+              a Markdown span ends.
+            * ``text(self, block, text)``: Executed when the parsing of text
               starts.
-            * ``leave_block``: Executed when the parsing a Markdown block ends.
-            * ``enter_span``: Executed when the parsing of a Markdown span
-              starts.
-            * ``leave_span``: Executed when the parsing of a Markdown span
-              ends.
-            * ``text``: Executed when the parsing of text starts ends.
-            * ``command``: Executed when a mdpo HTML command is found.
-            * ``msgid``: Executed when a msgid is going to be stored.
-            * ``link_reference``: Executed when a link reference is going to be
-              stored.
+            * ``command(self, mdpo_command, comment, original command)``:
+              Executed when a mdpo HTML command is found.
+            * ``msgid(self, msgid, msgstr, msgctxt, tcomment, flags)``:
+              Executed when a msgid is going to be stored.
+            * ``link_reference(self, target, href, title)``: Executed when a
+              link reference is going to be stored.
+
+            All ``self`` arguments are an instance of Md2Po parser. You can
+            take advanced control of the parsing process manipulating the
+            state of the parser. For example, if you want to skip a certain
+            msgid to be included, you can do:
+
+            .. code-block:: python
+
+               def msgid_event(self, msgid, *args):
+                   if msgid == 'foo':
+                       self._disable_next_line = True
 
     Examples:
         >>> content = 'Some text with `inline code`'
