@@ -84,6 +84,7 @@ class Po2Md:
         '_codespan_start_index',
         '_codespan_backticks',
         '_codespan_inside_current_msgid',
+        '_aspan_inside_current_msgid',
         '_inside_quoteblock',
         '_current_aspan_target',
         '_current_aspan_href',
@@ -109,7 +110,12 @@ class Po2Md:
             DEFAULT_MD4C_GENERIC_PARSER_EXTENSIONS,
         )
 
-        self.events = kwargs.get('events', {})
+        self.events = {}
+        if 'events' in kwargs:
+            for event_name, functions in kwargs['events'].items():
+                self.events[event_name] = (
+                    [functions] if callable(functions) else functions
+                )
 
         self._current_msgid = ''
         self._current_msgctxt = None
@@ -166,26 +172,26 @@ class Po2Md:
         self.link_end_string = kwargs.get('link_end_string', ']')
 
         self._enterspan_replacer = {
-            md4c.SpanType.STRONG: self.bold_start_string,
-            md4c.SpanType.EM: self.italic_start_string,
-            md4c.SpanType.CODE: self.code_start_string,
-            md4c.SpanType.A: self.link_start_string,
+            md4c.SpanType.STRONG.value: self.bold_start_string,
+            md4c.SpanType.EM.value: self.italic_start_string,
+            md4c.SpanType.CODE.value: self.code_start_string,
+            md4c.SpanType.A.value: self.link_start_string,
         }
 
         self._leavespan_replacer = {
-            md4c.SpanType.STRONG: self.bold_end_string,
-            md4c.SpanType.EM: self.italic_end_string,
-            md4c.SpanType.CODE: self.code_end_string,
-            md4c.SpanType.A: self.link_end_string,
+            md4c.SpanType.STRONG.value: self.bold_end_string,
+            md4c.SpanType.EM.value: self.italic_end_string,
+            md4c.SpanType.CODE.value: self.code_end_string,
+            md4c.SpanType.A.value: self.link_end_string,
         }
 
         if 'wikilinks' in self.extensions:
             self.wikilink_start_string = kwargs.get('link_end_string', '[[')
             self.wikilink_end_string = kwargs.get('link_end_string', ']]')
 
-            self._enterspan_replacer[md4c.SpanType.WIKILINK] = \
+            self._enterspan_replacer[md4c.SpanType.WIKILINK.value] = \
                 self.wikilink_start_string
-            self._leavespan_replacer[md4c.SpanType.WIKILINK] = \
+            self._leavespan_replacer[md4c.SpanType.WIKILINK.value] = \
                 self.wikilink_end_string
 
         self._inside_htmlblock = False
@@ -208,6 +214,7 @@ class Po2Md:
         self._current_aspan_href = None
         self._link_references = None
         self._current_imgspan = {}
+        self._aspan_inside_current_msgid = False
 
         # current table head alignments
         self._current_thead_aligns = []
@@ -336,7 +343,10 @@ class Po2Md:
             translation = '\n'.join(lines)
         elif self._inside_pblock:
             # wrap paragraphs fitting with markdownlint
-            if self._codespan_inside_current_msgid:
+            if (
+                self._codespan_inside_current_msgid
+                or self._aspan_inside_current_msgid
+            ):
                 # fix codespans wrapping
                 lines = fixwrap_codespans(
                     translation.split('\n'),
@@ -360,6 +370,7 @@ class Po2Md:
 
         self._codespan_inside_current_msgid = False
         self._aimg_title_inside_current_msgid = False
+        self._aspan_inside_current_msgid = False
 
     def _save_current_line(self):
         # strip all spaces according to unicodedata database ignoring newlines,
@@ -374,9 +385,9 @@ class Po2Md:
                 not self._current_line or self._current_line[0] != '>'
         ):
             self._current_line += '> '
-        if block.value == md4c.BlockType.P:
+        if block is md4c.BlockType.P:
             self._inside_pblock = True
-        elif block.value == md4c.BlockType.CODE:
+        elif block is md4c.BlockType.CODE:
             self._inside_codeblock = True
             indent = ''
 
@@ -386,20 +397,21 @@ class Po2Md:
                     self._save_current_line()
                 indent += '   ' * len(self._current_list_type)
 
-            if 'fence_char' in details:
+            if details['fence_char'] is not None:
                 self._current_line += '{}{}'.format(
                     indent,
                     details['fence_char']*3,
                 )
-            if details['lang']:
-                self._current_line += details['lang'][0][1]
-            if 'fence_char' not in details:
+                if details['lang']:
+                    self._current_line += details['lang'][0][1]
+            else:
                 self._inside_indented_codeblock = True
+
             if self._current_line:
                 self._save_current_line()
-        elif block.value == md4c.BlockType.H:
+        elif block is md4c.BlockType.H:
             self._current_line += '%s ' % ('#' * details['level'])
-        elif block.value == md4c.BlockType.LI:
+        elif block is md4c.BlockType.LI:
             if self._current_list_type[-1][0] == 'ol':
                 # inside OL
                 if len(self._ol_marks) > 1:
@@ -423,53 +435,53 @@ class Po2Md:
                 self._current_list_type[-1][-1].append(details['is_task'])
             self._inside_liblock = True
             self._inside_liblock_first_p = True
-        elif block.value == md4c.BlockType.UL:
+        elif block is md4c.BlockType.UL:
             if self._current_list_type:
                 self._save_current_msgid()
                 self._save_current_line()
             self._current_list_type.append(['ul', []])
             self._ul_marks.append(details['mark'])
-        elif block.value == md4c.BlockType.OL:
+        elif block is md4c.BlockType.OL:
             self._current_list_type.append(['ol', []])
             self._ol_marks.append([0, details['mark_delimiter']])
-        elif block.value == md4c.BlockType.HR:
+        elif block is md4c.BlockType.HR:
             if not self._inside_liblock:
                 self._current_line += '---\n\n'
             else:
                 # inside lists, the separator '---' can't be used
                 self._current_line += '***'
-        elif block.value == md4c.BlockType.TR:
+        elif block is md4c.BlockType.TR:
             self._current_line += '   ' * len(self._current_list_type)
             if self._current_line.startswith('>    '):
                 self._current_line = self._current_line.replace('> ', '')
-        elif block.value == md4c.BlockType.TH:
+        elif block is md4c.BlockType.TH:
             if self._inside_quoteblock:
                 if not self._current_line.replace(' ', '') == '>':
                     self._current_line = removesuffix(self._current_line, '> ')
             self._current_line += '| '
             self._current_thead_aligns.append(details['align'].value)
-        elif block.value == md4c.BlockType.TD:
+        elif block is md4c.BlockType.TD:
             if self._inside_quoteblock:
                 if not self._current_line.replace(' ', '') == '>':
                     self._current_line = removesuffix(self._current_line, '> ')
             self._current_line += '| '
-        elif block.value == md4c.BlockType.QUOTE:
+        elif block is md4c.BlockType.QUOTE:
             if self._inside_liblock:
                 self._save_current_msgid()
                 self._save_current_line()
             self._inside_quoteblock = True
-        elif block.value == md4c.BlockType.TABLE:
+        elif block is md4c.BlockType.TABLE:
             if self._current_list_type and not self._inside_quoteblock:
                 if self._current_line:
                     self._save_current_line()
                 self._save_current_line()
-        elif block.value == md4c.BlockType.HTML:
+        elif block is md4c.BlockType.HTML:
             self._inside_htmlblock = True
 
     def leave_block(self, block, details):
         # print('LEAVE BLOCK', block.name, details)
 
-        if block.value == md4c.BlockType.P:
+        if block is md4c.BlockType.P:
             self._save_current_msgid()
 
             if self._inside_liblock:
@@ -496,15 +508,14 @@ class Po2Md:
                 self._current_line = '>'
                 self._save_current_line()
 
-        elif block.value == md4c.BlockType.CODE:
+        elif block is md4c.BlockType.CODE:
             self._save_current_msgid()
             self._inside_codeblock = False
-            self._inside_indented_codeblock = False
 
             indent = ''
             if self._inside_liblock:
                 indent += '   ' * len(self._current_list_type)
-            if 'fence_char' in details:
+            if not self._inside_indented_codeblock:
                 if self._inside_liblock:
                     self._save_current_line()
                 self._current_line += '{}{}'.format(
@@ -515,9 +526,10 @@ class Po2Md:
             self._save_current_line()
             if not self._inside_liblock:
                 # prevent two newlines after indented code block
-                if 'fence_char' in details:
+                if not self._inside_indented_codeblock:
                     self._save_current_line()
-        elif block.value == md4c.BlockType.H:
+            self._inside_indented_codeblock = False
+        elif block is md4c.BlockType.H:
             self._save_current_msgid()
             if not self._inside_quoteblock:
                 self._current_line += '\n'
@@ -526,33 +538,33 @@ class Po2Md:
             self._save_current_line()
             if self._inside_quoteblock:
                 self._current_line += '> '
-        elif block.value == md4c.BlockType.LI:
+        elif block is md4c.BlockType.LI:
             self._save_current_msgid()
             self._inside_liblock = False
             if self._current_line:
                 self._save_current_line()
-        elif block.value == md4c.BlockType.UL:
+        elif block is md4c.BlockType.UL:
             self._ul_marks.pop()
             self._current_list_type.pop()
             if self._inside_quoteblock:
                 self._current_line += '> '
             if not self._ul_marks and self._outputlines[-1]:
                 self._save_current_line()
-        elif block.value == md4c.BlockType.OL:
+        elif block is md4c.BlockType.OL:
             self._ol_marks.pop()
             self._current_list_type.pop()
             if self._inside_quoteblock:
                 self._current_line += '> '
             if not self._ol_marks and self._outputlines[-1]:
                 self._save_current_line()
-        elif block.value in (md4c.BlockType.TH, md4c.BlockType.TD):
+        elif block is md4c.BlockType.TH or block is md4c.BlockType.TD:
             self._save_current_msgid()
             self._current_line += ' '
-        elif block.value == md4c.BlockType.TR:
+        elif block is md4c.BlockType.TR:
             if not self._current_thead_aligns:
                 self._current_line += '|'
                 self._save_current_line()
-        elif block.value == md4c.BlockType.THEAD:
+        elif block is md4c.BlockType.THEAD:
             # build thead separator
             thead_separator = ''
             if self._inside_quoteblock:
@@ -587,16 +599,16 @@ class Po2Md:
                 thead_separator,
             )
             self._save_current_line()
-        elif block.value == md4c.BlockType.QUOTE:
+        elif block is md4c.BlockType.QUOTE:
             if self._outputlines[-1] == '>':
                 self._outputlines.pop()
             if not self._inside_liblock:
                 self._save_current_line()
             self._inside_quoteblock = False
-        elif block.value == md4c.BlockType.TABLE:
+        elif block is md4c.BlockType.TABLE:
             if not self._inside_quoteblock and not self._current_list_type:
                 self._save_current_line()
-        elif block.value == md4c.BlockType.HTML:
+        elif block is md4c.BlockType.HTML:
             self._inside_htmlblock = False
 
     def enter_span(self, span, details):
@@ -607,7 +619,9 @@ class Po2Md:
         except KeyError:
             pass
 
-        if span.value == md4c.SpanType.A:
+        if span is md4c.SpanType.A:
+            self._aspan_inside_current_msgid = True
+
             if self._link_references is None:
                 self._link_references = parse_link_references(self.content)
 
@@ -629,22 +643,22 @@ class Po2Md:
                         self._current_aspan_target = target
                         break
 
-        elif span.value == md4c.SpanType.CODE:
+        elif span is md4c.SpanType.CODE:
             self._inside_codespan = True
             self._codespan_start_index = len(self._current_msgid)-1
             self._codespan_inside_current_msgid = True
-        elif span.value == md4c.SpanType.IMG:
+        elif span is md4c.SpanType.IMG:
             self._current_imgspan['title'] = '' if not details['title'] \
                 else details['title'][0][1]
             self._current_imgspan['src'] = details['src'][0][1]
             self._current_imgspan['text'] = ''
-        elif span.value == md4c.SpanType.WIKILINK:
+        elif span is md4c.SpanType.WIKILINK:
             self._current_wikilink_target = details['target'][0][1]
 
     def leave_span(self, span, details):
         # print("LEAVE SPAN", span.name, details)
 
-        if span.value == md4c.SpanType.WIKILINK:
+        if span is md4c.SpanType.WIKILINK:
             self._current_msgid += polib.escape(self._current_wikilink_target)
             self._current_wikilink_target = None
 
@@ -653,7 +667,7 @@ class Po2Md:
         except KeyError:
             pass
 
-        if span.value == md4c.SpanType.A:
+        if span is md4c.SpanType.A:
             if self._current_aspan_target:
                 self._current_msgid += f'[{self._current_aspan_target}]'
                 self._current_aspan_target = None
@@ -667,13 +681,13 @@ class Po2Md:
                         )
                     self._current_msgid += ')'
             self._current_aspan_href = None
-        elif span.value == md4c.SpanType.CODE:
+        elif span is md4c.SpanType.CODE:
             self._inside_codespan = False
             self._current_msgid += (
                 self._codespan_backticks * self.code_end_string
             )
             self._codespan_backticks = None
-        elif span.value == md4c.SpanType.IMG:
+        elif span is md4c.SpanType.IMG:
             self._current_msgid += '![{}]({}'.format(
                 self._current_imgspan['text'],
                 self._current_imgspan['src'],
@@ -741,14 +755,18 @@ class Po2Md:
             self._disable_next_line = False
             self._disable = False
 
-            pre_event = self.events.get('link_reference')
+            # 'link_reference' event
+            pre_events = self.events.get('link_reference')
 
             _references_added = []  # don't repeat references
             for target, href, title in self._link_references:
-
-                # 'link_reference' event
-                if pre_event and pre_event(self, target, href, title) is False:
-                    continue
+                if pre_events:
+                    skip = False
+                    for event in pre_events:
+                        if event(self, target, href, title) is False:
+                            skip = True
+                    if skip:
+                        continue
 
                 href_part = '{}{}'.format(
                     f' {href}' if href else '',
@@ -854,8 +872,9 @@ def pofile_to_markdown(
             of the translation process is skipped by po2md. The available
             events are:
 
-            * ``link_reference``: Executed when each reference link is being
-                written in the output (at the end of the translation process).
+            * ``link_reference(self, target, href, title)``: Executed when each
+              reference link is being written in the output (at the end of the
+              translation process).
 
     Returns:
         str: Markdown output file with translated content.
